const API_KEY = 'YOUR_UNSPLASH_API_KEY'; // Replace with actual API key
const wallpaperGrid = document.getElementById('wallpaperGrid');
const loading = document.getElementById('loading');
let page = 1;

async function fetchWallpapers(query = '') {
  loading.style.display = 'block';
  try {
    const url = query
      ? `https://api.unsplash.com/search/photos?page=${page}&query=${query}&per_page=20`
      : `https://api.unsplash.com/photos?page=${page}&per_page=20`;
    
    const response = await fetch(url, {
      headers: {
        'Authorization': `Client-ID ${API_KEY}`
      }
    });
    
    const data = await response.json();
    const images = query ? data.results : data;
    
    images.forEach(image => {
      const card = createWallpaperCard(image);
      wallpaperGrid.appendChild(card);
    });
  } catch (error) {
    console.error('Error fetching wallpapers:', error);
  } finally {
    loading.style.display = 'none';
  }
}

function createWallpaperCard(image) {
  const card = document.createElement('div');
  card.className = 'wallpaper-card';
  
  const img = document.createElement('img');
  img.src = image.urls.regular;
  img.alt = image.alt_description || 'Wallpaper';
  img.loading = 'lazy';
  
  card.appendChild(img);
  
  card.addEventListener('click', () => {
    window.open(image.urls.full, '_blank');
  });
  
  return card;
}

// Infinite scroll
window.addEventListener('scroll', () => {
  if (window.innerHeight + window.scrollY >= document.body.offsetHeight - 1000) {
    page++;
    fetchWallpapers();
  }
});

// Search functionality
const searchBtn = document.getElementById('searchBtn');
const searchInput = document.getElementById('search');

searchBtn.addEventListener('click', () => {
  const query = searchInput.value.trim();
  wallpaperGrid.innerHTML = '';
  page = 1;
  fetchWallpapers(query);
});

searchInput.addEventListener('keypress', (e) => {
  if (e.key === 'Enter') {
    searchBtn.click();
  }
});

// Category filters
document.querySelectorAll('.categories button').forEach(button => {
  button.addEventListener('click', () => {
    document.querySelector('.categories .active').classList.remove('active');
    button.classList.add('active');
    wallpaperGrid.innerHTML = '';
    page = 1;
    fetchWallpapers(button.dataset.category === 'all' ? '' : button.dataset.category);
  });
});

// Initial load
fetchWallpapers();
